#!/bin/bash

SCRIPT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
FROM_PATH=
TO_PATH=$SCRIPT_PATH

SHOW_USAGE=False

while [[ $# -gt 0 ]]
do
    key="$1"
    case $key in
        -h|--h|-help|--help)
            SHOW_USAGE=True
            ;;
        --from|-f)
            FROM_PATH="$2"
            shift
            ;;
        --to|-t)
            TO_PATH="$2"
            shift
            ;;
        *)
            echo "Error: Unsupported parameter specified: \"$key\""
            echo ""
            SHOW_USAGE=True
            ;;
    esac
    shift
done

if [ $SHOW_USAGE == "True" ];then
    cat <<EOH
relocate.sh: script to relocate libraries from one path to another. This script updates
paths stored in files (such as config scripts) after the file have been moved. It does
not move any file.

Usage: relocate.sh [-h|--help] [--from|-f /old/path/prefix] [--to|-t /new/path/prefix]

Example:
  relocate.sh --from /usr/local --to /Users/foo/Documents/libs_for_scummvm
EOH
    exit 0
fi

# If the FROM_PATH was not specified, extract it from the sdl-config script
if [ "$FROM_PATH" == "" ];then
    if [ -f $SCRIPT_PATH/bin/sdl2-config ]; then
        FROM_PATH=`$SCRIPT_PATH/bin/sdl2-config --prefix`
    elif [ -f $SCRIPT_PATH/bin/sdl-config ]; then
        FROM_PATH=`$SCRIPT_PATH/bin/sdl-config --prefix`
    else
        echo "WARNING: Cannot find sdl-config or sdl2-config script."
        FROM_PATH="/usr/local"
    fi
fi

echo "Relocating libraries from $FROM_PATH to $TO_PATH"

binfiles="sdl2-config sdl-config autopoint freetype-config glib-gettextize libmikmod-config libpng-config libpng16-config pcre-config curl-config wx-config"
for binfile in $binfiles
do
    file=$SCRIPT_PATH/bin/$binfile
    if [ -f "$file" ]; then
        echo "Updating $file..."
        sed -i'.orig' -e "s|${FROM_PATH}|${TO_PATH}|g" "$file"
    fi
done

for file in $SCRIPT_PATH/lib/pkgconfig/*.pc
do
    if [ -f "$file" ]; then
        echo "Updating $file..."
        sed -i'.orig' -e "s|${FROM_PATH}|${TO_PATH}|g" "$file"
    fi
done

for file in $SCRIPT_PATH/lib/*.la $SCRIPT_PATH/lib/*/*.la  $SCRIPT_PATH/lib/*/*/*.la
do
    if [ -f "$file" ]; then
        echo "Updating $file..."
        sed -i'.orig' -e "s|${FROM_PATH}|${TO_PATH}|g" "$file"
    fi
done

otherfiles="lib/cmake/SDL2/sdl2-config.cmake lib/wx/config/osx_cocoa-unicode-3.0 lib/wx/config/osx_cocoa-unicode-static-3.0 lib/wx/include/osx_cocoa-unicode-3.0/wx/setup.h lib/wx/include/osx_cocoa-unicode-static-3.0/wx/setup.h "
for of in $otherfiles
do
    file=$SCRIPT_PATH/$of
    if [ -f "$file" ]; then
        echo "Updating $file..."
        sed -i'.orig' -e "s|${FROM_PATH}|${TO_PATH}|g" "$file"
    fi
done
